@@ -38,7 +38,8 @@
 #include <libanjuta/anjuta-plugin-handle.h>
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/anjuta-glue-factory.h>
-#include <libanjuta/anjuta-glue-cpp.h>
+#include <libanjuta/anjuta-glue-c.h>
+#include <libanjuta/interfaces/ianjuta-plugin-loader.h>
 
 enum
 {
@@ -70,7 +71,7 @@ struct _AnjutaPluginManagerPriv
 	GList        *plugin_dirs;
 	GList        *available_plugins;
 	
-	/* Indexes */
+	/* Indexes => plugin handles */
 	GHashTable   *plugins_by_interfaces;
 	GHashTable   *plugins_by_name;
 	GHashTable   *plugins_by_description;
@@ -85,6 +86,7 @@ struct _AnjutaPluginManagerPriv
 	GHashTable   *remember_plugins;
 };
 
+/* Available plugins page treeview */
 enum {
 	COL_ACTIVABLE,
 	COL_ENABLED,
@@ -93,7 +95,15 @@ enum {
 	COL_PLUGIN,
 	N_COLS
 };
-	
+
+/* Remembered plugins page treeview */
+enum {
+	COL_REM_ICON,
+	COL_REM_NAME,
+	COL_REM_PLUGIN_KEY,
+	N_REM_COLS
+};
+
 /* Plugin class types */
 
 static GHashTable  *plugin_types = NULL;
@@ -106,6 +116,9 @@ static GHashTable* plugin_set_update (AnjutaPluginManager *plugin_manager,
 									  AnjutaPluginHandle* selected_plugin,
 									  gboolean load);
 
+static GType get_plugin_loader_type (AnjutaPluginManager *plugin_manager,
+								  const gchar *language);
+
 GQuark 
 anjuta_plugin_manager_error_quark (void)
 {
@@ -511,10 +524,11 @@ activate_plugin (AnjutaPluginManager *plugin_manager,
 {
 	AnjutaPluginManagerPriv *priv;
 	GType type;
+	GType glue_type;
 	GObject *ret;
-	gchar* lang;
 	const gchar *plugin_id;
-	AnjutaPluginDescription *plugin_desc;
+	const gchar *language;
+	gboolean resident;
 	
 	priv = plugin_manager->priv;
 	
@@ -524,32 +538,18 @@ activate_plugin (AnjutaPluginManager *plugin_manager,
 	}
 	
 	plugin_id = anjuta_plugin_handle_get_id (plugin);
-	plugin_desc = anjuta_plugin_handle_get_description (plugin);
 	
-	if (anjuta_plugin_description_get_locale_string (plugin_desc,
-													 "Anjuta Plugin",
-													 "Language", &lang))
+	resident = anjuta_plugin_handle_get_resident (plugin);
+	language = anjuta_plugin_handle_get_language (plugin);
+	
+	glue_type = get_plugin_loader_type (plugin_manager, language);
+	if (glue_type == G_TYPE_INVALID)
 	{
-		if (g_str_equal(lang, "C++"))
-		{
-			char **pieces;
-			pieces = g_strsplit (plugin_id, ":", -1);
-			ret = anjuta_glue_cpp_load_plugin (anjuta_glue_factory, pieces[0], pieces[1]);
-			g_strfreev (pieces);
-			if (ret == NULL)
-			{
-				g_set_error (error, ANJUTA_PLUGIN_MANAGER_ERROR,
-							 ANJUTA_PLUGIN_MANAGER_ERROR_INVALID_TYPE,
-							 _("Invalid plugin: %s"), plugin_id);
-				return NULL;
-			}
-			g_object_set (ret, "shell", priv->shell, NULL);
-			g_signal_connect (ret, "activated",
-							  G_CALLBACK (on_plugin_activated), plugin);
-			g_signal_connect (ret, "deactivated",
-							  G_CALLBACK (on_plugin_deactivated), plugin);
-			return ret;
-		}
+		g_set_error (error, ANJUTA_PLUGIN_MANAGER_ERROR,
+					 ANJUTA_PLUGIN_MANAGER_ERROR_INVALID_TYPE,
+					 _("Invalid plugin: %s"), plugin_id);
+		
+		return NULL;
 	}
 	
 	type = GPOINTER_TO_UINT (g_hash_table_lookup (plugin_types, plugin_id));
@@ -560,9 +560,11 @@ activate_plugin (AnjutaPluginManager *plugin_manager,
 		/* DEBUG_PRINT ("Loading: %s", plugin_id); */
 		pieces = g_strsplit (plugin_id, ":", -1);
 		type = anjuta_glue_factory_get_object_type (anjuta_glue_factory,
-										     pieces[0], pieces[1]);
-		g_hash_table_insert (plugin_types, g_strdup (plugin_id),
-							 GUINT_TO_POINTER (type));
+										     pieces[0], pieces[1],
+										     resident, glue_type);
+		if (type != G_TYPE_INVALID)
+			g_hash_table_insert (plugin_types, g_strdup (plugin_id),
+								 GUINT_TO_POINTER (type));
 		g_strfreev (pieces);
 	}
 	
@@ -771,10 +773,10 @@ plugin_set_update (AnjutaPluginManager *plugin_manager,
 			if (should_load (priv->activated_plugins, selected_plugin, plugin))
 			{
 				GObject *plugin_obj;
+				GError *error = NULL;
 				plugin_obj = g_hash_table_lookup (priv->plugins_cache, plugin);
 				if (!plugin_obj)
 				{
-					GError *error = NULL;
 					plugin_obj = activate_plugin (plugin_manager, plugin,
 												  &error);
 				}
@@ -783,6 +785,27 @@ plugin_set_update (AnjutaPluginManager *plugin_manager,
 				{
 					anjuta_plugin_activate (ANJUTA_PLUGIN (plugin_obj));
 				}
+				else
+				{
+					if (error)
+					{
+						gchar* message = g_strdup_printf (_("Could not load %s\n"
+							"This usually means that your installation is corrupted.\n"
+							"The error message leading to this was:\n%s"), 
+														  anjuta_plugin_handle_get_name (selected_plugin),
+														  error->message);
+						GtkWidget* dialog = gtk_message_dialog_new (NULL, 
+												GTK_DIALOG_MODAL,
+												GTK_MESSAGE_ERROR,
+												GTK_BUTTONS_OK,
+												message);
+						gtk_dialog_run (GTK_DIALOG (dialog));
+						gtk_widget_destroy (dialog);
+						
+						g_error_free (error);
+						g_free(message);
+					}
+				}
 			}
 		}
 	}
@@ -983,6 +1006,88 @@ populate_plugin_model (AnjutaPluginManager *plugin_manager,
 	}
 }
 
+static GtkWidget *
+create_remembered_plugins_tree (void)
+{
+	GtkListStore *store;
+	GtkWidget *tree;
+	GtkCellRenderer *renderer;
+	GtkTreeViewColumn *column;
+
+	store = gtk_list_store_new (N_REM_COLS, GDK_TYPE_PIXBUF, G_TYPE_STRING,
+								G_TYPE_STRING);
+	tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
+	
+	column = gtk_tree_view_column_new ();
+	renderer = gtk_cell_renderer_pixbuf_new ();
+	gtk_tree_view_column_pack_start (column, renderer, FALSE);
+	gtk_tree_view_column_add_attribute (column, renderer, "pixbuf",
+										COL_REM_ICON);
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start (column, renderer, FALSE);
+	gtk_tree_view_column_add_attribute (column, renderer, "markup",
+										COL_REM_NAME);
+	gtk_tree_view_column_set_sizing (column,
+									 GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	gtk_tree_view_column_set_title (column, _("Preferred plugins"));
+	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
+	gtk_tree_view_set_expander_column (GTK_TREE_VIEW (tree), column);
+	
+	g_object_unref (store);
+	return tree;
+}
+
+static void
+foreach_remembered_plugin (gpointer key, gpointer value, gpointer user_data)
+{
+	AnjutaPluginDescription *desc = (AnjutaPluginDescription *) value;
+	GtkListStore *store = GTK_LIST_STORE (user_data);
+	AnjutaPluginManager *manager = g_object_get_data (G_OBJECT (store),
+													  "plugin-manager");
+	AnjutaPluginHandle *plugin =
+		g_hash_table_lookup (manager->priv->plugins_by_description, desc);
+	g_return_if_fail (plugin != NULL);
+	
+	if (anjuta_plugin_handle_get_name (plugin) &&
+		anjuta_plugin_handle_get_description (plugin))
+	{
+		GtkTreeIter iter;
+		gchar *text;
+		
+		text = g_markup_printf_escaped ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
+										anjuta_plugin_handle_get_name (plugin),
+										anjuta_plugin_handle_get_about (plugin));
+
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+							COL_REM_NAME, text,
+							COL_REM_PLUGIN_KEY, key,
+							-1);
+		if (anjuta_plugin_handle_get_icon_path (plugin))
+		{
+			GdkPixbuf *icon;
+			icon = gdk_pixbuf_new_from_file_at_size (anjuta_plugin_handle_get_icon_path (plugin),
+													 48, 48, NULL);
+			if (icon) {
+				gtk_list_store_set (store, &iter,
+									COL_REM_ICON, icon, -1);
+				gdk_pixbuf_unref (icon);
+			}
+		}
+		g_free (text);
+	}
+}
+
+static void
+populate_remembered_plugins_model (AnjutaPluginManager *plugin_manager,
+								   GtkListStore *store)
+{
+	AnjutaPluginManagerPriv *priv = plugin_manager->priv;
+	gtk_list_store_clear (store);
+	g_hash_table_foreach (priv->remember_plugins, foreach_remembered_plugin,
+						  store);
+}
+
 static void
 on_show_all_plugins_toggled (GtkToggleButton *button, GtkListStore *store)
 {
@@ -995,21 +1100,62 @@ on_show_all_plugins_toggled (GtkToggleButton *button, GtkListStore *store)
 						   !gtk_toggle_button_get_active (button));
 }
 
+static void
+on_forget_plugin_clicked (GtkWidget *button, GtkTreeView *view)
+{
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+	GtkTreeSelection *selection = gtk_tree_view_get_selection (view);
+	if (gtk_tree_selection_get_selected (selection, &model, &iter))
+	{
+		gchar *plugin_key;
+		AnjutaPluginManager *manager = g_object_get_data (G_OBJECT (model),
+														  "plugin-manager");
+		gtk_tree_model_get (model, &iter, COL_REM_PLUGIN_KEY, &plugin_key, -1);
+		g_hash_table_remove (manager->priv->remember_plugins, plugin_key);
+		gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+		g_free (plugin_key);
+	}
+}
+
+static void
+on_forget_plugin_sel_changed (GtkTreeSelection *selection,
+							  GtkWidget *button)
+{
+	GtkTreeIter iter;
+	
+	if (gtk_tree_selection_get_selected (selection, NULL, &iter))
+		gtk_widget_set_sensitive (button, TRUE);
+	else
+		gtk_widget_set_sensitive (button, FALSE);
+}
+
 static GtkWidget *
 create_plugin_page (AnjutaPluginManager *plugin_manager)
 {
+	GtkWidget *notebook;
+	GtkWidget *page_label;
 	GtkWidget *vbox;
 	GtkWidget *checkbutton;
 	GtkWidget *tree;
 	GtkWidget *scrolled;
 	GtkListStore *store;
-
+	GtkWidget *hbox;
+	GtkWidget *display_label;
+	GtkWidget *forget_button;
+	GtkTreeSelection *selection;
+	
+	notebook = gtk_notebook_new ();
+	
+	/* Plugins page */
 	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 10);
+	page_label = gtk_label_new (_("Plugins"));
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, page_label);
 	
 	checkbutton = gtk_check_button_new_with_label (_("Only show user activatable plugins"));
 	gtk_container_set_border_width (GTK_CONTAINER (checkbutton), 10);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), TRUE);
-	gtk_widget_show (checkbutton);
 	gtk_box_pack_start (GTK_BOX (vbox), checkbutton, FALSE, FALSE, 0);
 	
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
@@ -1023,24 +1169,210 @@ create_plugin_page (AnjutaPluginManager *plugin_manager)
 	tree = create_plugin_tree ();
 	store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (tree)));
 
-	populate_plugin_model (plugin_manager,
-						   GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (tree))),
-						   NULL, plugin_manager->priv->activated_plugins, FALSE);
+	populate_plugin_model (plugin_manager, store, NULL,
+						   plugin_manager->priv->activated_plugins, FALSE);
 	
 	gtk_container_add (GTK_CONTAINER (scrolled), tree);
 	g_object_set_data (G_OBJECT (store), "plugin-manager", plugin_manager);
 
-	gtk_widget_show_all (vbox);
-	
-	if (plugin_manager->priv->status)
-		anjuta_status_add_widget (plugin_manager->priv->status, vbox);
 	
 	g_object_set_data (G_OBJECT (checkbutton), "__plugin_manager", plugin_manager);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled",
 					  G_CALLBACK (on_show_all_plugins_toggled),
 					  store);
 	
-	return vbox;
+	/* Remembered plugin */
+	vbox = gtk_vbox_new (FALSE, 10);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 10);
+	
+	display_label = gtk_label_new (_("These are the plugins selected by you "
+									 "when Anjuta prompted to choose one of "
+									 "many suitable plugins. Removing the "
+									 "preferred plugin will let Anjuta prompt "
+									 "you again to choose different plugin."));
+	gtk_label_set_line_wrap (GTK_LABEL (display_label), TRUE);
+	gtk_box_pack_start (GTK_BOX (vbox), display_label, FALSE, FALSE, 0);
+
+	page_label = gtk_label_new (_("Preferred plugins"));
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, page_label);
+	
+	scrolled = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
+									     GTK_SHADOW_IN);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
+									GTK_POLICY_AUTOMATIC,
+									GTK_POLICY_AUTOMATIC);
+	gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 0);
+	
+	tree = create_remembered_plugins_tree ();
+	store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (tree)));
+
+	gtk_container_add (GTK_CONTAINER (scrolled), tree);
+	g_object_set_data (G_OBJECT (store), "plugin-manager", plugin_manager);
+	populate_remembered_plugins_model (plugin_manager, store);
+	
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+	forget_button = gtk_button_new_with_label ("Forget selected plugin");
+	gtk_widget_set_sensitive (forget_button, FALSE);
+	gtk_box_pack_end (GTK_BOX (hbox), forget_button, FALSE, FALSE, 0);
+	
+	g_signal_connect (forget_button, "clicked",
+					  G_CALLBACK (on_forget_plugin_clicked),
+					  tree);
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
+	g_signal_connect (selection, "changed",
+					  G_CALLBACK (on_forget_plugin_sel_changed),
+					  forget_button);
+	
+	/* For cursor status */
+	
+	gtk_widget_show_all (notebook);
+	if (plugin_manager->priv->status)
+		anjuta_status_add_widget (plugin_manager->priv->status, notebook);
+	return notebook;
+}
+
+static GList *
+property_to_list (const char *value)
+{
+	GList *l = NULL;
+	char **split_str;
+	char **p;
+	
+	split_str = g_strsplit (value, ",", -1);
+	for (p = split_str; *p != NULL; p++) {
+		l = g_list_prepend (l, g_strdup (g_strstrip (*p)));
+	}
+	g_strfreev (split_str);
+	return l;
+}
+
+static GType
+get_plugin_loader_type (AnjutaPluginManager *plugin_manager,
+								  const gchar *language)
+{
+	AnjutaPluginManagerPriv *priv;
+	AnjutaPluginHandle *plugin;
+	GList *loader_plugins, *node;
+	GList *valid_plugins;
+	GObject *obj = NULL;
+	
+	g_return_val_if_fail (ANJUTA_IS_PLUGIN_MANAGER (plugin_manager), G_TYPE_INVALID);
+
+	
+	if ((language == NULL) || (g_ascii_strcasecmp (language, "C") == 0))
+	{
+		/* Support of C plugin is built-in */
+		return ANJUTA_GLUE_TYPE_C_PLUGIN;
+	}
+	
+	priv = plugin_manager->priv;
+	plugin = NULL;
+		
+	/* Find all plugins implementing the IAnjutaPluginLoader interface. */
+	loader_plugins = g_hash_table_lookup (priv->plugins_by_interfaces, "IAnjutaPluginLoader");
+
+	/* Create a list of loader supporting this language */
+	node = loader_plugins;
+	valid_plugins = NULL;
+	while (node)
+	{
+		AnjutaPluginDescription *desc;
+		gchar *val;
+		GList *vals = NULL;
+		GList *l_node;
+		gboolean found;
+		
+		plugin = node->data;
+
+		desc = anjuta_plugin_handle_get_description (plugin);
+		if (anjuta_plugin_description_get_string (desc, "Plugin Loader", "SupportedLanguage", &val))		
+		{
+			if (val != NULL)
+			{	
+				vals = property_to_list (val);
+				g_free (val);
+			}
+		}
+		
+		found = FALSE;
+		l_node = vals;
+		while (l_node)
+		{
+			if (!found && (g_ascii_strcasecmp (l_node->data, language) == 0))
+			{
+				found = TRUE;
+			}
+			g_free (l_node->data);
+			l_node = g_list_next (l_node);
+		}
+		g_list_free (vals);
+
+		if (found)
+		{
+			valid_plugins = g_list_prepend (valid_plugins, plugin);
+		}
+		
+		node = g_list_next (node);
+	}
+	
+	/* Find the first installed plugin from the valid plugins */
+	node = valid_plugins;
+	while (node)
+	{
+		plugin = node->data;
+		obj = g_hash_table_lookup (priv->activated_plugins, plugin);
+		if (obj) break;
+		node = g_list_next (node);
+	}
+
+	/* If no plugin is installed yet, do something */
+	if ((obj == NULL) && valid_plugins && g_list_length (valid_plugins) == 1)
+	{
+		/* If there is just one plugin, consider it selected */
+		plugin = valid_plugins->data;
+		
+		/* Install and return it */
+		plugin_set_update (plugin_manager, plugin, TRUE);
+		obj = g_hash_table_lookup (priv->activated_plugins, plugin);
+	}
+	else if ((obj == NULL) && valid_plugins)
+	{
+		/* Prompt the user to select one of these plugins */
+
+		GList *descs = NULL;
+		node = valid_plugins;
+		while (node)
+		{
+			plugin = node->data;
+			descs = g_list_prepend (descs, anjuta_plugin_handle_get_description (plugin));
+			node = g_list_next (node);
+		}
+		descs = g_list_reverse (descs);
+		obj = anjuta_plugin_manager_select_and_activate (plugin_manager,
+								  _("Select a plugin"),
+								  _("Please select a plugin to activate"),
+								  descs);
+		g_list_free (descs);
+	}
+	g_list_free (valid_plugins);
+
+	if (obj != NULL)
+	{
+		/* Get type of glue object */
+		IAnjutaPluginLoader *loader;
+			
+		loader = IANJUTA_PLUGIN_LOADER (ANJUTA_PLUGIN(obj));
+		
+		return ianjuta_plugin_loader_glue_plugin_get_type (loader, NULL);
+	}
+	
+	/* No plugin implementing this interface found */
+	g_warning ("No plugin found to load a %s plugin.", language);
+	
+	return G_TYPE_INVALID;
 }
 
 /**
@@ -1125,8 +1457,8 @@ anjuta_plugin_manager_get_plugin (AnjutaPluginManager *plugin_manager,
 		}
 		descs = g_list_reverse (descs);
 		obj = anjuta_plugin_manager_select_and_activate (plugin_manager,
-									  "Select a plugin",
-									  "Please select a plugin to activate",
+									  _("Select a plugin"),
+									  _("Please select a plugin to activate"),
 									  descs);
 		g_list_free (descs);
 		return obj;
@@ -1265,21 +1597,6 @@ anjuta_plugin_manager_get_dialog (AnjutaPluginManager *plugin_manager)
 	return create_plugin_page (plugin_manager);
 }
 
-static GList *
-property_to_list (const char *value)
-{
-	GList *l = NULL;
-	char **split_str;
-	char **p;
-	
-	split_str = g_strsplit (value, ",", -1);
-	for (p = split_str; *p != NULL; p++) {
-		l = g_list_prepend (l, g_strdup (g_strstrip (*p)));
-	}
-	g_strfreev (split_str);
-	return l;
-}
-
 GList*
 anjuta_plugin_manager_query (AnjutaPluginManager *plugin_manager,
 							 const gchar *section_name,
