@@ -171,9 +171,48 @@ libanjuta_iface_cclosure_marshal_VOID__INT_CHAR (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING (./libanjuta-iface-marshallers.list:7) */
+/* VOID:POINTER (./libanjuta-iface-marshallers.list:7) */
 
-/* VOID:STRING,UINT,UINT (./libanjuta-iface-marshallers.list:8) */
+/* VOID:STRING (./libanjuta-iface-marshallers.list:8) */
+
+/* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:9) */
+void
+libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
+                                                      GValue       *return_value,
+                                                      guint         n_param_values,
+                                                      const GValue *param_values,
+                                                      gpointer      invocation_hint,
+                                                      gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer     data1,
+                                                    gpointer     arg_1,
+                                                    gpointer     arg_2,
+                                                    gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            data2);
+}
+
+/* VOID:STRING,UINT,UINT (./libanjuta-iface-marshallers.list:10) */
 void
 libanjuta_iface_cclosure_marshal_VOID__STRING_UINT_UINT (GClosure     *closure,
                                                          GValue       *return_value,
@@ -212,7 +251,44 @@ libanjuta_iface_cclosure_marshal_VOID__STRING_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT (./libanjuta-iface-marshallers.list:9) */
+/* VOID:UINT (./libanjuta-iface-marshallers.list:11) */
 
-/* VOID:VOID (./libanjuta-iface-marshallers.list:10) */
+/* VOID:UINT,UINT (./libanjuta-iface-marshallers.list:12) */
+void
+libanjuta_iface_cclosure_marshal_VOID__UINT_UINT (GClosure     *closure,
+                                                  GValue       *return_value,
+                                                  guint         n_param_values,
+                                                  const GValue *param_values,
+                                                  gpointer      invocation_hint,
+                                                  gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer     data1,
+                                                guint        arg_1,
+                                                guint        arg_2,
+                                                gpointer     data2);
+  register GMarshalFunc_VOID__UINT_UINT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__UINT_UINT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_uint (param_values + 1),
+            g_marshal_value_peek_uint (param_values + 2),
+            data2);
+}
+
+/* VOID:VOID (./libanjuta-iface-marshallers.list:13) */
 
