@@ -103,7 +103,7 @@ read_memory_block (gulong address, gulong length, gpointer user_data)
 	{	
 		ianjuta_cpu_debugger_inspect_memory (
 				IANJUTA_CPU_DEBUGGER (mem->debugger),
-				(const gchar *)address,
+				(guint)address,
 				(guint)length,
 				(IAnjutaDebuggerCallback)on_memory_block_read,
 				mem,
