@@ -1,3 +1,4 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /* 
  * watch.c Copyright (C) 2000 Kh. Naba Kumar Singh
  * 
@@ -23,6 +24,10 @@
 #include "debug_tree.h"
 #include "plugin.h"
 
+/*#define DEBUG*/
+#include <libanjuta/anjuta-debug.h>
+#include <libanjuta/interfaces/ianjuta-editor-selection.h>
+#include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 
 /* Type
@@ -39,8 +44,6 @@ struct _ExprWatch
 	/* Menu action */
 	GtkActionGroup *action_group;
 	GtkActionGroup *toggle_group;
-	
-	GtkWidget* middle_click_menu;
 };
 
 struct _InspectDialog
@@ -82,6 +85,7 @@ debug_tree_inspect_evaluate_dialog (ExprWatch * ew, const gchar* expression)
 {
 	GladeXML *gxml;
 	gint reply;
+	gchar *new_expr;
 	// const gchar *value;
 	InspectDialog dlg;
 	IAnjutaDebuggerVariable var = {NULL, NULL, NULL, NULL, FALSE, -1};
@@ -114,35 +118,15 @@ debug_tree_inspect_evaluate_dialog (ExprWatch * ew, const gchar* expression)
 		{
 		case GTK_RESPONSE_OK:
 			/* Add in watch window */
-			#if 0
-			expression = gtk_entry_get_text (GTK_ENTRY (dlg.name_entry));
-		    var.expression = expression;
-			debug_tree_add_watch (ew->debug_tree, &var, FALSE);
-		    #endif
-		    continue;
-		case GTK_RESPONSE_APPLY:
-			/* Update value */
-			#if 0
-			expression = gtk_entry_get_text (GTK_ENTRY (dlg.name_entry));
-			value = gtk_entry_get_text (GTK_ENTRY (dlg.value_treeview));
-		    gtk_widget_ref (dlg.value_treeview);
-		    if (ew->debugger != NULL)
+			new_expr = debug_tree_get_first (dlg.tree);
+
+			if (new_expr != NULL)
 			{
-				ianjuta_debugger_evaluate (ew->debugger, expression, value, NULL, &dlg, NULL);
-				ianjuta_debugger_inspect (ew->debugger, expression, on_entry_updated, &dlg, NULL);
+		    	var.expression = new_expr;
+				debug_tree_add_watch (ew->debug_tree, &var, FALSE);
+				g_free (new_expr);
 			}
-			#endif
-			continue;
-		case GTK_RESPONSE_ACCEPT:
-			/* Update variable */
-			#if 0
-			expression = gtk_entry_get_text (GTK_ENTRY (dlg.name_entry));
-		    gtk_widget_ref (dlg.value_treeview);
-		    debug_tree_remove_all (dlg.tree);
-		    var.expression = expression;
-			debug_tree_add_watch (dlg.tree, &var, FALSE);
-		    #endif
-			continue;
+			break;
 		default:
 			break;
 		}
@@ -229,7 +213,7 @@ on_debug_tree_inspect (GtkAction *action, gpointer user_data)
 	GObject *obj;
 	IAnjutaDocumentManager *docman = NULL;
 	IAnjutaEditor *te = NULL;
-	const gchar *expression = NULL;
+	gchar *expression = NULL;
 	
 	/* Get current editor and line */
 	obj = anjuta_shell_get_object (ANJUTA_PLUGIN (ew->plugin)->shell,
@@ -238,9 +222,15 @@ on_debug_tree_inspect (GtkAction *action, gpointer user_data)
 	if (docman != NULL)
 	{
 		te = ianjuta_document_manager_get_current_editor (docman, NULL);
+		expression = ianjuta_editor_selection_get (IANJUTA_EDITOR_SELECTION (te), NULL);
+		if (expression == NULL)
+		{
+			expression = ianjuta_editor_get_current_word (IANJUTA_EDITOR (te), NULL);
+		}
 	}
 	
 	debug_tree_inspect_evaluate_dialog (ew, expression);
+	g_free (expression);
 }
 
 static void
@@ -328,6 +318,7 @@ on_debug_tree_button_press (GtkWidget *widget, GdkEventButton *bevent, gpointer
 		GtkAction *action;
 		AnjutaUI *ui;
 		GtkTreeIter iter;
+		GtkWidget *middle_click_menu;
 
 		ui = anjuta_shell_get_ui (ew->plugin->shell, NULL);
 		action = anjuta_ui_get_action (ui, "ActionGroupWatchToggle", "ActionDmaAutoUpdateWatch");
@@ -344,14 +335,9 @@ on_debug_tree_button_press (GtkWidget *widget, GdkEventButton *bevent, gpointer
 		action = anjuta_ui_get_action (ui, "ActionGroupWatch", "ActionDmaEditWatch");
 		gtk_action_set_sensitive (GTK_ACTION (action), FALSE);   // FIXME: Not implemented
 		
-		if (ew->middle_click_menu == NULL)
-		{
-			ew->middle_click_menu = gtk_ui_manager_get_widget (GTK_UI_MANAGER (ui), "/PopupWatch");
-			g_object_ref (ew->middle_click_menu);
-			//g_signal_connect (debug_tree_get_tree_widget(ew->debug_tree), "hide", G_CALLBACK (on_debug_tree_hide_popup), NULL);  
-			
-		}
-		gtk_menu_popup (GTK_MENU (ew->middle_click_menu), NULL, NULL, NULL, NULL,
+		middle_click_menu = gtk_ui_manager_get_widget (GTK_UI_MANAGER (ui), "/PopupWatch");
+		g_return_val_if_fail (middle_click_menu != NULL, FALSE);
+		gtk_menu_popup (GTK_MENU (middle_click_menu), NULL, NULL, NULL, NULL,
 						bevent->button, bevent->time);
 	}
 	
@@ -559,12 +545,6 @@ expr_watch_destroy (ExprWatch * ew)
 	anjuta_ui_remove_action_group (ui, ew->action_group);
 	anjuta_ui_remove_action_group (ui, ew->toggle_group);
 
-	if (ew->middle_click_menu != NULL)
-	{
-		g_object_unref (ew->middle_click_menu);
-		gtk_widget_destroy (ew->middle_click_menu);
-	}
-	
 	debug_tree_free (ew->debug_tree);
 	gtk_widget_destroy (ew->scrolledwindow);
 	g_free (ew);
