@@ -21,6 +21,7 @@
 #include <config.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
 
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-status.h>
@@ -643,6 +644,7 @@ on_create_submenu (gpointer user_data)
 		if (name)
 		{
 			menuitem = gtk_image_menu_item_new_with_mnemonic (name);
+			g_free(name);
 			gtk_widget_show (menuitem);
 			g_object_set_data (G_OBJECT (menuitem), "__plugin_desc", desc);
 			g_signal_connect (G_OBJECT (menuitem), "activate",
@@ -1289,6 +1291,15 @@ iloader_load (IAnjutaFileLoader *loader, const gchar *uri,
 	
 	g_return_val_if_fail (uri != NULL, NULL);
 	vfs_uri = gnome_vfs_uri_new (uri);
+	
+	if (!gnome_vfs_uri_exists (vfs_uri))
+	{
+		launch_application_failure (ANJUTA_PLUGIN_FILE_LOADER (loader),
+									uri, GNOME_VFS_ERROR_NOT_FOUND);
+		gnome_vfs_uri_unref (vfs_uri);
+		return NULL;
+	}
+	
 	new_uri = gnome_vfs_uri_to_string (vfs_uri,
 									   GNOME_VFS_URI_HIDE_FRAGMENT_IDENTIFIER);
 	mime_type = anjuta_util_get_uri_mime_type (new_uri);
