@@ -27,7 +27,10 @@
 #include <libanjuta/interfaces/ianjuta-editor-cell.h>
 #include <libanjuta/interfaces/ianjuta-editor-language.h>
 #include <libanjuta/interfaces/ianjuta-editor-selection.h>
+#include <libanjuta/interfaces/ianjuta-editor-assist.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
+#include <libanjuta/interfaces/ianjuta-symbol.h>
+
 
 #include "plugin.h"
 
@@ -450,13 +453,13 @@ set_indentation_param (CppJavaPlugin* plugin, const gchar *param,
 	DEBUG_PRINT ("Setting indent param: %s = %s", param, value);
 	if (strcasecmp (param, "indent-tabs-mode") == 0)
 	{
-		if (strcasecmp (value, "t"))
+		if (strcasecmp (value, "t") == 0)
 		{
 			plugin->param_use_spaces = 0;
 			ianjuta_editor_set_use_spaces (IANJUTA_EDITOR (plugin->current_editor),
 										   FALSE, NULL);
 		}
-		else if (strcasecmp (value, "t"))
+		else if (strcasecmp (value, "nil") == 0)
 		{
 			plugin->param_use_spaces = 1;
 			ianjuta_editor_set_use_spaces (IANJUTA_EDITOR (plugin->current_editor),
@@ -490,7 +493,8 @@ parse_mode_line (CppJavaPlugin *plugin, const gchar *modeline)
 		{
 			g_strstrip (keyval[0]);
 			g_strstrip (keyval[1]);
-			set_indentation_param (plugin, keyval[0], keyval[1]);
+			set_indentation_param (plugin, g_strchug (keyval[0]),
+                                   g_strchug (keyval[1]));
 		}
 		g_strfreev (keyval);
 		ptr++;
@@ -586,13 +590,14 @@ initialize_indentation_params (CppJavaPlugin *plugin)
 		
 		if (comment_begun)
 			g_string_append_c (comment_text, ch);
+		
 	}
 	while (ianjuta_iterable_next (iter, NULL));
 	
-	DEBUG_PRINT ("Comment text: %s", comment_text->str);
-	
+	/* DEBUG_PRINT ("Comment text: %s", comment_text->str);*/
 	if (comment_text->len > 0)
 	{
+		
 		/* First comment found */
 		gchar *modeline = extract_mode_line (comment_text->str);
 		if (modeline)
@@ -604,6 +609,223 @@ initialize_indentation_params (CppJavaPlugin *plugin)
 	g_string_free (comment_text, TRUE);
 }
 
+static void on_assist_begin(IAnjutaEditorAssist* assist, gchar* context, gchar* trigger, CppJavaPlugin* lang_plugin)
+{
+	gint position;
+	
+	DEBUG_PRINT("assist-begin: %s", context);
+	/* General word completion */
+	if (context == NULL || !strlen(context))
+	{
+		ianjuta_editor_assist_suggest(assist, NULL, -1, NULL);
+		return;
+	}
+	if (!trigger)
+	{
+		IAnjutaIterable* iter = 
+			ianjuta_symbol_manager_search (lang_plugin->symbol_browser,
+										   IANJUTA_SYMBOL_TYPE_FUNCTION|
+										   IANJUTA_SYMBOL_TYPE_CLASS|
+										   IANJUTA_SYMBOL_TYPE_ENUM,
+											context, TRUE, TRUE, NULL);
+		if (iter)
+		{
+			do
+			{
+				const gchar* name = ianjuta_symbol_name(IANJUTA_SYMBOL(iter), NULL);
+				if (name != NULL)
+				{
+					lang_plugin->suggestions = g_list_append(lang_plugin->suggestions,
+													 g_strdup(name));
+				}
+				else
+					break;
+			}
+			while (ianjuta_iterable_next(iter, NULL));
+			position = ianjuta_editor_get_position(IANJUTA_EDITOR(assist), NULL)
+				- strlen(context);
+		}
+	}
+	else if (g_str_equal(trigger, "::"))
+	{
+		IAnjutaIterable* iter = 
+			ianjuta_symbol_manager_get_members (lang_plugin->symbol_browser,
+											context, TRUE, NULL);
+		if (iter)
+		{
+			do
+			{
+				const gchar* name = ianjuta_symbol_name(IANJUTA_SYMBOL(iter), NULL);
+				if (name != NULL)
+				{
+					lang_plugin->suggestions = g_list_append(lang_plugin->suggestions,
+													 g_strdup(name));
+				}
+			}
+			while (ianjuta_iterable_next(iter, NULL));
+		}
+		position = ianjuta_editor_get_position(IANJUTA_EDITOR(assist), NULL);
+	}
+	else if (g_str_equal(trigger, ".") || g_str_equal(trigger, "->"))
+	{
+		/* TODO: Find the type of context by parsing the file somehow and
+		search for the member as it is done with the :: context */
+	}
+	/* More than 100 suggestions are likely to break X Windows...
+	We better wait until more context arrives
+	TODO: Make user configurable */
+	if (g_list_length(lang_plugin->suggestions) < 100)
+		ianjuta_editor_assist_suggest(assist, lang_plugin->suggestions, position, NULL);
+}
+
+static void assist_cleanup(CppJavaPlugin* lang_plugin)
+{
+	g_list_foreach(lang_plugin->suggestions, (GFunc) g_free, NULL);
+	g_list_free(lang_plugin->suggestions);
+	lang_plugin->suggestions = NULL;
+}
+
+static void on_assist_end(IAnjutaEditorAssist* assist, CppJavaPlugin* lang_plugin)
+{
+	DEBUG_PRINT("assist-end");
+	assist_cleanup(lang_plugin);
+}
+
+static void on_assist_cancel(IAnjutaEditorAssist* assist, CppJavaPlugin* lang_plugin)
+{
+	DEBUG_PRINT("assist-cancel");
+	assist_cleanup(lang_plugin);
+}
+
+static void on_assist_chosen(IAnjutaEditorAssist* assist, gint selection, CppJavaPlugin* lang_plugin)
+{
+	DEBUG_PRINT("assist-chosen: %d", selection);
+	gchar* assistance = g_list_nth_data(lang_plugin->suggestions, selection);
+	ianjuta_editor_assist_react(assist, selection, assistance, NULL);  
+	assist_cleanup(lang_plugin);
+}
+
+static void on_assist_update(IAnjutaEditorAssist* assist, gchar* context, CppJavaPlugin* lang_plugin)
+{
+	DEBUG_PRINT("assist-update: %s", context);
+	GList* suggestions = NULL;
+	GList* sug;
+	if (!strlen(context))
+	{
+		ianjuta_editor_assist_suggest(assist, NULL, -1, NULL);
+		return;
+	}
+	for (sug = lang_plugin->suggestions; sug != NULL; sug = sug->next)
+	{
+		gchar* suggestion = sug->data;
+		if (g_str_has_prefix(suggestion, context))
+		{
+			suggestions = g_list_append(suggestions, g_strdup(suggestion));
+		}
+	}
+	assist_cleanup(lang_plugin);
+	lang_plugin->suggestions = suggestions;
+	ianjuta_editor_assist_suggest(assist, lang_plugin->suggestions, -1, NULL);
+}
+
+static gchar*
+get_context(IAnjutaEditorCell* iter, IAnjutaEditor* editor)
+{
+	gint end;
+	gint begin;
+	gchar* utf8 = NULL;
+	gunichar unichar;
+	end = ianjuta_iterable_get_position(IANJUTA_ITERABLE(iter), NULL);
+	do
+	{
+		ianjuta_iterable_previous(IANJUTA_ITERABLE(iter), NULL);		
+		utf8 = ianjuta_editor_cell_get_character(iter, NULL);
+		unichar = g_utf8_get_char(utf8);
+		g_free(utf8);
+	}
+	while (!g_unichar_isspace(unichar));
+	begin = ianjuta_iterable_get_position(IANJUTA_ITERABLE(iter), NULL) + 1;
+	return ianjuta_editor_get_text(editor, begin, end - begin, NULL);
+}
+
+static gchar*
+dot_member_parser(IAnjutaEditor* editor, gint position)
+{
+	IAnjutaEditorCell* iter = IANJUTA_EDITOR_CELL(ianjuta_editor_get_cell_iter(editor, position, NULL));
+	if (ianjuta_iterable_previous(IANJUTA_ITERABLE(iter), NULL) &&
+		ianjuta_editor_cell_get_char(iter, 0, NULL) == '.')
+	{
+		return get_context(iter, editor);
+	}
+	else
+	{
+		return NULL;
+	}
+}
+
+static gchar*
+pointer_member_parser(IAnjutaEditor* editor, gint position)
+{
+	IAnjutaEditorCell* iter = IANJUTA_EDITOR_CELL(ianjuta_editor_get_cell_iter(editor, position, NULL));
+	if (ianjuta_iterable_previous(IANJUTA_ITERABLE(iter), NULL) &&
+		ianjuta_editor_cell_get_char(iter, 0, NULL) == '>' &&
+		ianjuta_iterable_previous(IANJUTA_ITERABLE(iter), NULL) &&
+		ianjuta_editor_cell_get_char(iter, 0, NULL) == '-')
+	{
+		return get_context(iter, editor);
+	}
+	else
+	{
+		return NULL;
+	}
+}
+
+static gchar*
+cpp_member_parser(IAnjutaEditor* editor, gint position)
+{
+	IAnjutaEditorCell* iter = IANJUTA_EDITOR_CELL(ianjuta_editor_get_cell_iter(editor, position, NULL));
+	if (ianjuta_iterable_previous(IANJUTA_ITERABLE(iter), NULL) &&
+		ianjuta_editor_cell_get_char(iter, 0, NULL) == ':' &&
+		ianjuta_iterable_previous(IANJUTA_ITERABLE(iter), NULL) &&
+		ianjuta_editor_cell_get_char(iter, 0, NULL) == ':')
+	{
+		return get_context(iter, editor);
+	}
+	else
+	{
+		return NULL;
+	}
+}
+
+
+static void
+install_assist(CppJavaPlugin* lang_plugin)
+{
+	IAnjutaEditorAssist* assist = IANJUTA_EDITOR_ASSIST(lang_plugin->current_editor);
+	ianjuta_editor_assist_add_trigger(assist, ".", dot_member_parser, NULL);
+	ianjuta_editor_assist_add_trigger(assist, "->", pointer_member_parser, NULL);
+	ianjuta_editor_assist_add_trigger(assist, "::", cpp_member_parser, NULL);	
+	g_signal_connect(G_OBJECT(assist), "assist_begin", G_CALLBACK(on_assist_begin), lang_plugin);
+	g_signal_connect(G_OBJECT(assist), "assist_end", G_CALLBACK(on_assist_end), lang_plugin);
+	g_signal_connect(G_OBJECT(assist), "assist_update", G_CALLBACK(on_assist_update), lang_plugin);
+	g_signal_connect(G_OBJECT(assist), "assist_chosen", G_CALLBACK(on_assist_chosen), lang_plugin);
+	g_signal_connect(G_OBJECT(assist), "assist_canceled", G_CALLBACK(on_assist_cancel), lang_plugin);
+}
+
+static void
+uninstall_assist(CppJavaPlugin* lang_plugin)
+{
+	IAnjutaEditorAssist* assist = IANJUTA_EDITOR_ASSIST(lang_plugin->current_editor);
+	ianjuta_editor_assist_remove_trigger(assist, ".", NULL);
+	ianjuta_editor_assist_remove_trigger(assist, "->", NULL);
+	ianjuta_editor_assist_remove_trigger(assist, "::", NULL);
+	g_signal_handlers_disconnect_by_func(assist, G_CALLBACK(on_assist_begin), lang_plugin);
+	g_signal_handlers_disconnect_by_func(assist, G_CALLBACK(on_assist_end), lang_plugin);
+	g_signal_handlers_disconnect_by_func(assist, G_CALLBACK(on_assist_update), lang_plugin);
+	g_signal_handlers_disconnect_by_func(assist, G_CALLBACK(on_assist_cancel), lang_plugin);
+	g_signal_handlers_disconnect_by_func(assist, G_CALLBACK(on_assist_chosen), lang_plugin);
+}
+
 static gint
 set_line_indentation (IAnjutaEditor *editor, gint line_num, gint indentation)
 {
@@ -909,12 +1131,52 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 	return line_indent;
 }
 
+/* Check if iter is inside comment or string. Begining of comment or string
+ * is not counted as inside.
+ */
+static gboolean
+is_iter_inside_comment_or_string (IAnjutaIterable *iter)
+{
+	IAnjutaEditorAttribute attrib;
+	
+	attrib = ianjuta_editor_cell_get_attribute (IANJUTA_EDITOR_CELL (iter),
+												NULL);
+	/* Check if we are *inside* comment or string. Begining of comment
+	 * or string does not count as inside.
+	 */
+	if (attrib == IANJUTA_EDITOR_COMMENT || attrib == IANJUTA_EDITOR_STRING)
+	{
+		/* Peek previous attrib and see what it was */
+		if (ianjuta_iterable_previous (iter, NULL))
+		{
+			attrib = ianjuta_editor_cell_get_attribute (IANJUTA_EDITOR_CELL
+														(iter),	NULL);
+			if (attrib == IANJUTA_EDITOR_COMMENT ||
+				attrib == IANJUTA_EDITOR_STRING)
+			{
+				/* We are inside comment or string */
+				return TRUE;
+			}
+			else
+			{
+				/* The comment or string just began, not inside.
+				 * Restore iter from the peek
+				 */
+				ianjuta_iterable_next (iter, NULL);
+			}
+		}
+		/* else, there is no previous and so we can't be inside comment
+		 * or string
+		 */
+	}
+	return FALSE;
+}
+
 static gint
 get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 						   gint line)
 {
 	IAnjutaIterable *iter;
-	IAnjutaEditorAttribute attrib;
 	gint line_indent = 0;
 	gint line_begin;
 	gint incomplete_statement = -1;
@@ -924,9 +1186,7 @@ get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 	line_begin = ianjuta_editor_get_line_begin_position (editor, line, NULL);
 	iter = ianjuta_editor_get_cell_iter (editor, line_begin, NULL);
 	
-	attrib = ianjuta_editor_cell_get_attribute (IANJUTA_EDITOR_CELL (iter),
-												NULL);
-	if (attrib == IANJUTA_EDITOR_COMMENT || attrib == IANJUTA_EDITOR_STRING)
+	if (is_iter_inside_comment_or_string (iter))
 	{
 		line_indent = get_line_indentation (editor, line - 1);
 	}
@@ -940,9 +1200,11 @@ get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 	do
 	{
 		gchar ch;
-		attrib = ianjuta_editor_cell_get_attribute (IANJUTA_EDITOR_CELL (iter),
-													NULL);
-		if (attrib == IANJUTA_EDITOR_COMMENT || attrib == IANJUTA_EDITOR_STRING)
+		/* Check if we are *inside* comment or string. Begining of comment
+		 * or string does not count as inside. If inside, just align with
+		 * previous indentation.
+		 */
+		if (is_iter_inside_comment_or_string (iter))
 		{
 			line_indent = get_line_indentation (editor, line - 1);
 			break;
@@ -1132,6 +1394,8 @@ install_support (CppJavaPlugin *lang_plugin)
 						  "char-added",
 						  G_CALLBACK (on_editor_char_inserted_cpp),
 						  lang_plugin);
+		if (IANJUTA_IS_EDITOR_ASSIST(lang_plugin->current_editor))
+			install_assist(lang_plugin);
 		initialize_indentation_params (lang_plugin);
 	}
 	else if (lang_plugin->current_language &&
@@ -1193,6 +1457,8 @@ on_value_added_current_editor (AnjutaPlugin *plugin, const gchar *name,
 	lang_plugin = ANJUTA_PLUGIN_CPP_JAVA (plugin);
 	lang_plugin->current_editor = g_value_get_object (value);
 	install_support (lang_plugin);
+	if (IANJUTA_IS_EDITOR_ASSIST(lang_plugin->current_editor))
+		install_assist(lang_plugin);
 	g_signal_connect (lang_plugin->current_editor, "language-changed",
 					  G_CALLBACK (on_editor_language_changed),
 					  plugin);
@@ -1207,6 +1473,8 @@ on_value_removed_current_editor (AnjutaPlugin *plugin, const gchar *name,
 	g_signal_handlers_disconnect_by_func (lang_plugin->current_editor,
 										  G_CALLBACK (on_editor_language_changed),
 										  plugin);
+	if (IANJUTA_IS_EDITOR_ASSIST(lang_plugin->current_editor))
+		uninstall_assist(lang_plugin);
 	uninstall_support (lang_plugin);
 	lang_plugin->current_editor = NULL;
 }
@@ -1288,6 +1556,10 @@ cpp_java_plugin_activate_plugin (AnjutaPlugin *plugin)
 								 on_value_added_current_editor,
 								 on_value_removed_current_editor,
 								 plugin);
+	
+	lang_plugin->symbol_browser = 
+		anjuta_shell_get_interface(plugin->shell, IAnjutaSymbolManager, NULL);
+	
 	return TRUE;
 }
 
@@ -1332,6 +1604,7 @@ cpp_java_plugin_instance_init (GObject *obj)
 	plugin->action_group = NULL;
 	plugin->current_editor = NULL;
 	plugin->current_language = NULL;
+	plugin->symbol_browser = NULL;
 	plugin->editor_watch_id = 0;
 	plugin->uiid = 0;
 }
