@@ -47,6 +47,7 @@ static AnjutaPreferences* prefs = NULL;
 
 #define FONT_THEME "sourceview.font.use_theme"
 #define FONT "sourceview.font"
+#define DESKTOP_FIXED_FONT "/desktop/gnome/interface/monospace_font_name"
 
 static int
 get_int(GConfEntry* entry)
@@ -62,7 +63,10 @@ get_bool(GConfEntry* entry)
 	/* Usually we would use get_bool but anjuta_preferences saves bool as int 
 		#409408
 	*/
-	return gconf_value_get_int(value);
+	if (value->type == GCONF_VALUE_BOOL)
+		return gconf_value_get_bool (value);
+	else
+		return gconf_value_get_int(value);
 }
 
 static void
@@ -211,7 +215,14 @@ on_gconf_notify_font_theme (GConfClient *gclient, guint cnxn_id,
 	
 	if (use_theme)
 	{
-		anjuta_view_set_font(sv->priv->view, TRUE, NULL);
+		gchar *desktop_fixed_font;
+		desktop_fixed_font =
+			gconf_client_get_string (gclient, DESKTOP_FIXED_FONT, NULL);
+		if (desktop_fixed_font)
+			anjuta_view_set_font(sv->priv->view, FALSE, desktop_fixed_font);
+		else
+			anjuta_view_set_font(sv->priv->view, TRUE, NULL);
+		g_free (desktop_fixed_font);
 	}
 	else
 		on_gconf_notify_font(NULL, 0, NULL, sv);
@@ -230,6 +241,21 @@ init_colors_and_fonts(Sourceview* sv)
 	{
 		on_gconf_notify_font(NULL, 0, NULL, sv);
 	}
+	else
+	{
+		GConfClient *gclient;
+                gchar *desktop_fixed_font;
+
+		gclient = gconf_client_get_default ();
+                desktop_fixed_font =
+                        gconf_client_get_string (gclient, DESKTOP_FIXED_FONT, NULL);
+                if (desktop_fixed_font)
+                        anjuta_view_set_font(sv->priv->view, FALSE, desktop_fixed_font);
+                else
+                        anjuta_view_set_font(sv->priv->view, TRUE, NULL);
+                g_free (desktop_fixed_font);
+		g_object_unref (gclient);
+	}
 	
 	if (!color_theme)
 	{
