@@ -22,7 +22,7 @@
 #define _SYMBOL_BROWSER_PLUGIN_H_
 
 #include <libanjuta/anjuta-plugin.h>
-#include <libanjuta/interfaces/ianjuta-message-manager.h>
+#include <libanjuta/anjuta-launcher.h>
 
 G_BEGIN_DECLS
 
@@ -66,7 +66,7 @@ struct _SymbolBrowserPlugin{
 	GList *gconf_notify_ids;
 	
 	gint locals_line_number;
-	IAnjutaMessageView* mesg_view;
+	AnjutaLauncher *launcher;
 };
 
 struct _SymbolBrowserPluginClass{
